@@ -26,6 +26,29 @@ class TestDumpNone(TestCase):
     DUMMY_CLASS = TestDumpNoneDummy
 
 
+class TestDumpListWithNoneDummy(TestCaseDummy):
+    def run(self, case: TestCase) -> Any:
+        super().run(case)
+        try:
+            return self.api.dumps({"key": [1, 2, 3, None, 5]})
+        except Exception as e:
+            return e
+
+    def result(self, out: Any) -> str:
+        replace_newline = lambda s: s.replace("\n", " ")
+        if isinstance(out, Exception):
+            return f"Raises {replace_newline(str(out))}"
+        return f"Dumps to `{out!r}`"
+
+
+class TestDumpListWithNone(TestCase):
+    """How the package dumps a list with `None` value in it.
+    Literally `<package>.dumps({"key": [1, 2, 3, None, 5]})`
+    """
+    HEADER = "Dumped value or error"
+    DUMMY_CLASS = TestDumpListWithNoneDummy
+
+
 class TestDumpValueNoneDummy(TestCaseDummy):
     def run(self, case: TestCase) -> Any:
         super().run(case)
@@ -40,7 +63,7 @@ class TestDumpValueNoneDummy(TestCaseDummy):
             return f"Raises {replace_newline(str(out))}"
         if out == "":
             return "Ignores the key (dumps to an empty string)"
-        return f"Dumps to `{replace_newline(out)}`"
+        return f"Dumps to `{replace_newline(repr(out))}`"
 
 
 class TestDumpValueNone(TestCase):
